import {
  ArrowLeftOutlined_default,
  LoadingOutlined_default,
  SwapRightOutlined_default,
  __toESM,
  button_default,
  config_provider_default,
  getState,
  i,
  i18n_default,
  input_default,
  postMessage,
  require_react,
  require_react_dom,
  select_default,
  setState,
  table_default,
  theme_default,
  useMessage
} from "./chunk-EHHB44CN.js";

// src/renderer/HomeIndex.tsx
var import_react3 = __toESM(require_react());
var import_react_dom = __toESM(require_react_dom());

// src/renderer/Home.tsx
var import_react2 = __toESM(require_react());

// src/renderer/hooks/useVscode.ts
var import_react = __toESM(require_react());
function useMessage2(eventName, handler, conditions = []) {
  let eventsName = Array.of();
  if (!Array.isArray(eventName)) {
    eventsName.push(eventName);
  } else {
    eventsName = eventName;
  }
  (0, import_react.useEffect)(() => {
    let isMounted = true;
    const eventListener = (event) => {
      const {
        data: { type, payload }
      } = event;
      if (isMounted && eventsName.includes(type)) {
        handler.call(null, payload, type);
      }
    };
    window.addEventListener("message", eventListener);
    return () => {
      isMounted = false;
      window.removeEventListener("message", eventListener);
    };
  }, [eventName, eventsName, conditions, handler]);
}

// src/renderer/Home.tsx
function Home() {
  var _a, _b, _c;
  const [home, setHome] = i({
    userInfo: getState("userInfo") || void 0,
    aidcList: getState("aidcList") || [],
    curAidcId: getState("curAidcId") || void 0,
    vscodeTheme: Number(window.VSCODE_THEME) || 1,
    workshopList: [],
    workshopHistoryList: [],
    vksIdList: [],
    isToc: window.IS_TOC || false,
    vksLoading: false
  });
  useMessage();
  useMessage2("updateVksLoading", (payload) => {
    console.log("updateVksLoading", payload);
    setHome((draft) => {
      draft.vksLoading = !!payload;
    });
  });
  useMessage2("updateHome", (payload) => {
    const { userInfo, aidcList = [], curAidcId, isToc } = payload;
    setHome((draft) => {
      draft.userInfo = userInfo;
      draft.aidcList = aidcList;
      draft.curAidcId = curAidcId;
      draft.isToc = isToc;
    });
    setState("userInfo", userInfo);
    setState("aidcList", aidcList);
    setState("curAidcId", curAidcId);
  });
  useMessage2("updateTheme", (payload) => {
    const { vscodeTheme } = payload;
    setHome((draft) => {
      draft.vscodeTheme = vscodeTheme;
    });
  });
  useMessage2("updateWorkshopData", (payload) => {
    const { workshopList = [], workshopHistoryList = [], vksIdList = [] } = payload;
    setHome((draft) => {
      draft.workshopList = workshopList;
      draft.workshopHistoryList = workshopHistoryList;
      draft.vksIdList = vksIdList;
    });
  });
  useMessage2("deleteHistory", (payload) => {
    setHome((draft) => {
      draft.workshopHistoryList = draft.workshopHistoryList.filter(
        (cur) => cur.workshopId !== payload
      );
    });
  });
  const onLogin = (isToB) => {
    postMessage({
      type: "executeCommand",
      data: {
        command: "Zetyunhost.loginZetyun",
        data: isToB
      }
    });
  };
  const onLogout = () => {
    postMessage({
      type: "executeCommand",
      data: {
        command: "Zetyunhost.logoutZetyun",
        data: null
      }
    });
  };
  const bgStyle = home.userInfo ? {
    backgroundImage: `url(${window.IMAGE_URL}/logo_bg.png)`,
    backgroundRepeat: "no-repeat",
    backgroundPosition: "right 20px bottom 20px",
    backgroundSize: "80px 80px",
    height: "100%",
    padding: "20px",
    minWidth: "300px"
  } : {
    backgroundImage: `url(${window.IMAGE_URL}/home_bg.png)`,
    backgroundSize: "cover",
    height: "100%",
    padding: "20px",
    minWidth: "300px"
  };
  const onGoWorkspace = () => {
    postMessage({
      type: "executeCommand",
      data: {
        command: "Zetyunhost.goTreeView",
        data: null
      }
    });
  };
  const onChangeAidc = (value) => {
    var _a2;
    setHome((draft) => {
      draft.curAidcId = value;
    });
    setState("curAidcId", value);
    console.log("curAidcId\uFF1A", value);
    postMessage({
      type: "executeCommand",
      data: {
        command: "Zetyunhost.changeAidc",
        data: (_a2 = home.aidcList) == null ? void 0 : _a2.find((cur) => cur.id === value)
      }
    });
  };
  const onWorkshopNameChange = (e, index) => {
    console.log("workshopName:", e.target.value, index);
    setHome((draft) => {
      draft.workshopHistoryList[index].workshopName = e.target.value;
    });
  };
  const onImportWorkshop = (record) => () => {
    const params = {
      name: record.workshopName,
      config: record.config
    };
    console.log("importWorkshop:", params);
    postMessage({
      type: "executeCommand",
      data: {
        command: "Zetyunhost.importHistoryWorkshop",
        data: {
          workshopId: record.workshopId,
          params
        }
      }
    });
  };
  const onDeleteWorkshop = (record) => {
    console.log("deleteWorkshop:", record);
    postMessage({
      type: "executeCommand",
      data: {
        command: "Zetyunhost.deleteHistoryWorkshop",
        data: record
      }
    });
  };
  const getWorkshopErrorRender = (record) => {
    if (record.workshopName === "") {
      return {
        status: "error",
        children: /* @__PURE__ */ import_react2.default.createElement("div", {
          style: { color: "red" }
        }, "Please enter the name")
      };
    } else if (home.workshopList.find((cur) => cur.name === record.workshopName)) {
      return {
        status: "error",
        children: /* @__PURE__ */ import_react2.default.createElement("div", {
          style: { color: "red" }
        }, "Workshop already exists")
      };
    } else if (!/^[a-zA-Z0-9._-]+$/.test(record.workshopName)) {
      return {
        status: "error",
        children: /* @__PURE__ */ import_react2.default.createElement("div", {
          style: { color: "red" }
        }, "Only supports letters, numbers and. _ -")
      };
    }
    return {
      status: "",
      children: null
    };
  };
  const columns = [
    {
      title: "Workshop",
      dataIndex: "workshopName",
      width: 130,
      render: (text, record, index) => {
        var _a2, _b2;
        return /* @__PURE__ */ import_react2.default.createElement(import_react2.default.Fragment, null, /* @__PURE__ */ import_react2.default.createElement(input_default, {
          status: (_a2 = getWorkshopErrorRender(record)) == null ? void 0 : _a2.status,
          value: text,
          onChange: (e) => onWorkshopNameChange(e, index),
          maxLength: 30
        }), (_b2 = getWorkshopErrorRender(record)) == null ? void 0 : _b2.children);
      }
    },
    {
      title: "VKS",
      dataIndex: ["config", "vksId"],
      width: 100,
      render: (text) => {
        var _a2;
        return ((_a2 = home.vksIdList.find((cur) => cur.id === text)) == null ? void 0 : _a2.clusterName) || "--";
      }
    },
    {
      title: "Action",
      width: 60,
      dataIndex: "action",
      render: (_, record) => {
        var _a2, _b2;
        return /* @__PURE__ */ import_react2.default.createElement(import_react2.default.Fragment, null, /* @__PURE__ */ import_react2.default.createElement(button_default, {
          style: {
            padding: "0",
            height: "20px",
            width: "auto",
            display: "block",
            marginBottom: "4px"
          },
          type: "link",
          disabled: ((_a2 = getWorkshopErrorRender(record)) == null ? void 0 : _a2.status) === "error" || !((_b2 = home.vksIdList.find((cur) => {
            var _a3;
            return cur.id === ((_a3 = record == null ? void 0 : record.config) == null ? void 0 : _a3.vksId);
          })) == null ? void 0 : _b2.clusterName),
          onClick: onImportWorkshop(record)
        }, "Import"), /* @__PURE__ */ import_react2.default.createElement(button_default, {
          style: { padding: "0", height: "20px", width: "auto", display: "block" },
          type: "link",
          onClick: () => onDeleteWorkshop(record)
        }, "Delete"));
      }
    }
  ];
  return /* @__PURE__ */ import_react2.default.createElement(config_provider_default, {
    theme: {
      algorithm: home.vscodeTheme === 2 ? theme_default.darkAlgorithm : theme_default.defaultAlgorithm,
      token: {
        colorPrimary: "#0078d4"
      },
      components: {
        Button: {
          fontWeight: "500"
        },
        Input: {
          colorBgContainer: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "#f3f3f3",
          colorBgContainerDisabled: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "#f3f3f3",
          colorBorder: "transparent"
        },
        InputNumber: {
          colorBgContainer: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "#f3f3f3",
          colorBgContainerDisabled: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "#f3f3f3",
          colorBorder: "transparent"
        },
        Select: {
          colorBgContainer: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "#e6e6e7",
          colorBgContainerDisabled: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "#e6e6e7"
        },
        Table: {
          colorBgContainer: home.vscodeTheme === 2 ? "rgba(255, 255, 255, 0.16)" : "rgba(10, 17, 26, 0.04)"
        }
      }
    }
  }, /* @__PURE__ */ import_react2.default.createElement("div", {
    style: bgStyle
  }, home.userInfo && /* @__PURE__ */ import_react2.default.createElement("div", null, /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { marginBottom: "40px" }
  }, /* @__PURE__ */ import_react2.default.createElement("span", {
    onClick: home.vksLoading ? null : onGoWorkspace,
    style: {
      width: "106px",
      height: "24px",
      borderRadius: "4px",
      padding: "7px 10px",
      background: home.vscodeTheme === 2 ? "rgba(255,255,255,0.16)" : "#dcdcdd",
      color: home.vscodeTheme === 2 ? "rgba(255,255,255,0.8)" : "#0A111A",
      cursor: home.vksLoading ? "not-allowed" : "pointer"
    }
  }, home.vksLoading ? /* @__PURE__ */ import_react2.default.createElement(LoadingOutlined_default, {
    style: { marginRight: "8px" }
  }) : /* @__PURE__ */ import_react2.default.createElement(ArrowLeftOutlined_default, {
    style: { marginRight: "8px" }
  }), i18n_default.t("home.backToWS"))), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { display: "flex", marginBottom: "34px" }
  }, /* @__PURE__ */ import_react2.default.createElement("div", null, /* @__PURE__ */ import_react2.default.createElement("img", {
    style: { width: "52px" },
    src: `${window.IMAGE_URL}/avator.png`
  })), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { marginLeft: "10px" }
  }, /* @__PURE__ */ import_react2.default.createElement("div", {
    style: {
      position: "relative",
      top: "-6px",
      fontSize: "20px",
      marginBottom: "8px",
      fontWeight: "600",
      color: home.vscodeTheme === 2 ? "#fff" : "#0A111A"
    }
  }, "Hello ", ((_a = home.userInfo) == null ? void 0 : _a.displayName) || ((_b = home.userInfo) == null ? void 0 : _b.userName), "!"), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: {
      fontWeight: "600",
      fontSize: "15px",
      background: "linear-gradient(to right, #c36eff 0%, #1d73ff 50%, #5364ff 100%)",
      backgroundClip: "text",
      color: "transparent"
    }
  }, home.isToc ? "Personal Account" : "Business Account"))), !home.isToc && /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { display: "flex", marginBottom: "24px" }
  }, /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { fontSize: "14px", minWidth: "105px" }
  }, i18n_default.t("home.aiCenter"), "\uFF1A"), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { flex: 1 }
  }, /* @__PURE__ */ import_react2.default.createElement(select_default, {
    disabled: home.vksLoading,
    size: "small",
    value: home.curAidcId,
    style: { width: "100%", maxWidth: "280px" },
    onChange: onChangeAidc,
    options: (_c = home.aidcList) == null ? void 0 : _c.map((cur) => ({ label: cur.nameEn, value: cur.id }))
  }))), !home.isToc && home.workshopHistoryList.length > 0 && /* @__PURE__ */ import_react2.default.createElement("div", {
    style: {
      position: "fixed",
      bottom: "120px",
      left: "20px",
      width: "calc(100% - 40px)",
      minWidth: "344px",
      maxWidth: "500px"
    }
  }, /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { fontSize: "20px", fontWeight: "500" }
  }, "History Workshop"), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { fontWeight: "200", margin: "16px 0" }
  }, "Workshops that are not in the currently selected AI Data Center cannot be imported."), /* @__PURE__ */ import_react2.default.createElement("div", null, /* @__PURE__ */ import_react2.default.createElement(table_default, {
    columns,
    dataSource: home.workshopHistoryList,
    pagination: false,
    rowKey: "workshopId",
    size: "small",
    scroll: { y: 244, x: "max-content" }
  }))), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: {
      position: "fixed",
      bottom: "20px",
      left: "20px",
      cursor: home.vksLoading ? "not-allowed" : "pointer"
    }
  }, /* @__PURE__ */ import_react2.default.createElement("div", {
    onClick: !home.vksLoading ? onLogout : null,
    style: {
      textAlign: "center",
      lineHeight: "26px",
      width: "100px",
      height: "30px",
      borderRadius: "14px",
      border: "1px solid",
      borderColor: home.vscodeTheme === 2 ? "#848484" : "#8d8e8e",
      color: home.vscodeTheme === 2 ? "#848484" : "#8d8e8e"
    }
  }, home.vksLoading && /* @__PURE__ */ import_react2.default.createElement(LoadingOutlined_default, {
    style: { marginRight: "8px" }
  }), i18n_default.t("home.logout")))), !home.userInfo && /* @__PURE__ */ import_react2.default.createElement("div", null, /* @__PURE__ */ import_react2.default.createElement("div", null, /* @__PURE__ */ import_react2.default.createElement("img", {
    style: { width: "21px", marginRight: "8px" },
    src: `${window.IMAGE_URL}/logo.png`
  }), /* @__PURE__ */ import_react2.default.createElement("span", {
    style: {
      color: "#fff",
      fontSize: "20px",
      fontWeight: "normal",
      position: "relative",
      top: "-2px"
    }
  }, "ALADDIN")), /* @__PURE__ */ import_react2.default.createElement("br", null), /* @__PURE__ */ import_react2.default.createElement("div", null, /* @__PURE__ */ import_react2.default.createElement("span", {
    style: {
      whiteSpace: "nowrap",
      fontSize: 14,
      fontWeight: "bold",
      background: "linear-gradient(to right,rgb(223, 250, 69) 0%, #CCFFFA 60%, #FF5454 100%)",
      backgroundClip: "text",
      color: "transparent"
    }
  }, i18n_default.t("home.serviceForDever")), /* @__PURE__ */ import_react2.default.createElement("br", null), /* @__PURE__ */ import_react2.default.createElement("span", {
    style: {
      whiteSpace: "nowrap",
      fontSize: 24,
      fontWeight: "bold",
      background: "linear-gradient(to right, rgb(223, 250, 69) 0%, #CCFFFA 60%, #FF5454 100%)",
      backgroundClip: "text",
      color: "transparent"
    }
  }, i18n_default.t("home.selfInnovate"))), /* @__PURE__ */ import_react2.default.createElement("br", null), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { color: "#fff", fontSize: "12px", marginBottom: "40px" }
  }, "Login to your account to start LLM development"), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { color: "#fff", fontSize: "12px", marginBottom: "20px" }
  }, "For organizations and teams:"), /* @__PURE__ */ import_react2.default.createElement("div", {
    onClick: () => onLogin(true),
    style: {
      cursor: "pointer",
      width: 220,
      height: 32,
      lineHeight: "32px",
      borderRadius: 32,
      display: "flex",
      justifyContent: "center",
      alignItems: "center",
      background: "#fff"
    }
  }, /* @__PURE__ */ import_react2.default.createElement("span", {
    style: {
      marginRight: "8px",
      fontWeight: "bold",
      fontSize: "15px",
      background: "linear-gradient(to right, #c36eff 0%, #1d73ff 50%, #5364ff 100%)",
      backgroundClip: "text",
      color: "transparent"
    }
  }, i18n_default.t("home.loginToB")), /* @__PURE__ */ import_react2.default.createElement(SwapRightOutlined_default, {
    style: { color: "#5364ff", fontWeight: "bold" }
  })), /* @__PURE__ */ import_react2.default.createElement("br", null), /* @__PURE__ */ import_react2.default.createElement("div", {
    style: { color: "#fff", fontSize: "12px", marginBottom: "20px" }
  }, "For personal account:"), /* @__PURE__ */ import_react2.default.createElement("div", {
    onClick: () => onLogin(false),
    style: {
      cursor: "pointer",
      width: 220,
      height: 32,
      lineHeight: "32px",
      borderRadius: 32,
      display: "flex",
      justifyContent: "center",
      alignItems: "center",
      background: "#fff"
    }
  }, /* @__PURE__ */ import_react2.default.createElement("span", {
    style: {
      marginRight: "8px",
      fontWeight: "bold",
      fontSize: "15px",
      background: "linear-gradient(to right, #c36eff 0%, #1d73ff 50%, #5364ff 100%)",
      backgroundClip: "text",
      color: "transparent"
    }
  }, i18n_default.t("home.loginToC")), /* @__PURE__ */ import_react2.default.createElement(SwapRightOutlined_default, {
    style: { color: "#5364ff", fontWeight: "bold" }
  })))));
}

// src/renderer/HomeIndex.tsx
(0, import_react_dom.render)(/* @__PURE__ */ import_react3.default.createElement(Home, null), document.getElementById("root"));
//# sourceMappingURL=home.js.map
